==> moniwiki-1.1.3-RC3-20081218.tgz: moniwiki/locale/fr/LC_MESSAGES/moniwiki.php <==
<?php

$_locale[" or click %s to fullsearch this page.\n"] =
   " ou cliquer sur %s pour faire une recherche en texte intgral de cette page.\n";
$_locale["\"%s\" is deleted !"] =
   "\"%s\" est effac !";
$_locale["\"%s\" is renamed !"] =
   "\"%s\" est renomm !";
$_locale["\"%s\" is updated"] =
   "\"%s\" est mis  jour";
$_locale["%d comment"] =
   "%d commentaire";
$_locale["%d comments"] =
   "%d commentaires";
$_locale["%d day(s) left until %s."] =
   "%d jour(s) restent avant %s.";
$_locale["%d day(s) passed from %s."] =
   "%d jour(s) se sont passs depuis %s.";
$_locale["%s has saved revisions"] =
   "%s est sauvegard";
$_locale["%s is commented successfully"] =
   "Vote russi";
$_locale["%s is not allowed to upload"] =
   "%s n'est pas une action valide";
$_locale["%s is not editable"] =
   "%s n'est pas ditable";
$_locale["%s is not valid action"] =
   "%s n'est pas une action valide";
$_locale["%s is saved"] =
   "%s est sauvegard";
$_locale["%s or %s"] =
   "%s ou %s";
$_locale["%s or alternativly, use one of these templates:\n"] =
   "%s ou alternativement, utiliser un de ces modles de page :\n";
$_locale["%s page is modified"] =
   "la page %s est modifi";
$_locale["--Select Category--"] =
   "-- Slectionner une catgorie";
$_locale["<b>Emphasis:</b> ''<i>italics</i>''; '''<b>bold</b>'''; '''''<b><i>bold italics</i></b>''''';\n''<i>mixed '''<b>bold</b>''' and italics</i>''; ---- horizontal rule.<br />\n<b>Headings:</b> = Title 1 =; == Title 2 ==; === Title 3 ===;\n==== Title 4 ====; ===== Title 5 =====.<br />\n<b>Lists:</b> space and one of * bullets; 1., a., A., i., I. numbered items;\n1.#n start numbering at n; space alone indents.<br />\n<b>Links:</b> JoinCapitalizedWords; [\"brackets and double quotes\"];\n[bracketed words];\nurl; [url]; [url label].<br />\n<b>Tables</b>: || cell text |||| cell text spanning two columns ||;\nno trailing white space allowed after tables or titles.<br />\n"] =
   "<b>Accentuation :</b> ''<i>italique</i>''; '''<b>gras</b>'''; '''''<b><i>italique gras</i></b>''''';\n''<i>mlange de '''<b>gras</b>''' et italique</i>''; ---- rgle horizontale.<br />\n<b>Enttes :</b> = Titre 1 =; == Titre 2 ==; === Titre 3 ===;\n==== Titre 4 ====; ===== Titre 5 =====.<br />\n<b>Listes :</b> un espace et une des * puces; 1., a., A., i., I. numrations ;\n1.#n commence  partir de n; l'espace seul provoque une indentation.<br />\n<b>Liens :</b> MotsAttachsEnMajuscules; [\"crochets et guillemets\"];\n[mots entre crochets];\nurl; [url]; [url label].<br />\n<b>Tableaux</b> : || cellule de texte |||| cellule de texte s'tendant sur deux colonnes ||;\nLes espaces aprs un tableau ou un titre ne sont pas autoriss.<br />\n";
$_locale["<b>horizontal rule</b> ---- is not applied on the blog mode."] =
   "<b>Une rgle horizontale</b> ---- ne s'applique pas au mode blog.";
$_locale["Add Blog"] =
   "Ajouter un blog";
$_locale["Add Blog entry to \"%s\""] =
   "Ajouter une entre de blog  \"%s\"";
$_locale["Add Comment to \"%s\""] =
   "Ajouter un commentaire  \"%s\"";
$_locale["Add comment"] =
   "Ajouter un commentaire";
$_locale["Anonymous"] =
   "Anonyme";
$_locale["Back to UserPreferences"] =
   "Retour  UserPreferences";
$_locale["Blog Changes"] =
   "ModificationsBlog";
$_locale["Blog entry \"%s\" added"] =
   "Entre de blog ajout  \"%s\"";
$_locale["Blog entry added"] =
   "Entre de blog ajout ";
$_locale["Blog entry added to \"%s\""] =
   "Entre de blog ajout  \"%s\"";
$_locale["BlogChanges"] =
   "ModificationsBlog";
$_locale["BlogChanges at %s"] =
   "ModificationsBlog at %s";
$_locale["Comment"] =
   "commentaire";
$_locale["Comment added to \"%s\""] =
   "Commentaire ajout  \"%s\"";
$_locale["Conflict error!"] =
   "Erreur de conflit !";
$_locale["Create new picture"] =
   "Crer un nouveau dessin";
$_locale["Create this page"] =
   "Crer cette page";
$_locale["Deeper"] =
   "Plus profond";
$_locale["Delete \"%s\" ?"] =
   "Effacer \"%s\" ?";
$_locale["Delete selected files"] =
   "Effacer les fichiers slectionns";
$_locale["DeletePage"] =
   "EffacerPage";
$_locale["Describe %s here"] =
   "Dcrire %s ici";
$_locale["Did you want to Backup your wiki ?"] =
   "Voulez vous faire une sauvegarde de votre wiki ?";
$_locale["Difference between r%s and r%s"] =
   "Diffrence entre r%s et r%s";
$_locale["Difference between r%s and the current"] =
   "Diffrence entre r%s et la version courante";
$_locale["Difference between versions"] =
   "Diffrence entre les versions";
$_locale["Directory '%s' is deleted"] =
   "Le rpertoire '%s' est effac";
$_locale["Do you want to customize your quicklinks ?"] =
   "Voulez vous mettre  jour vos liens rapides ?";
$_locale["Do you want to subscribe \"%s\" ?"] =
   "Voulez vous abonner  \"%s\" ?";
$_locale["Don't add a signature"] =
   "Ne pas ajouter de signature";
$_locale["Draw new picture"] =
   "Faire un nouveau dessin";
$_locale["Edit Image"] =
   "diter l'image";
$_locale["Edit drawing"] =
   "diter le dessin";
$_locale["Edit new drawing"] =
   "diter un nouveau dessin";
$_locale["EditText"] =
   "ditionTexte";
$_locale["EmailNotification is not activated"] =
   "EmailNotification n'est pas activ";
$_locale["Error: Don't try to overwrite it"] =
   "Erreur : n'essayez pas d'crire par dessus";
$_locale["Error: No entry found!"] =
   "Erreur : entre non trouv !";
$_locale["Error: Page Not found !"] =
   "Erreur : page non trouv !";
$_locale["Error: tarball does not exists"] =
   "Erreur : l'archive n'existe pas";
$_locale["Fail to \"%s\" !"] =
   "Impossible de pouvoir \"%s\" !";
$_locale["Fail to chmod \"%s\" !"] =
   "Impossible de pouvoir \"%s\" !";
$_locale["Fail to copy \"%s\" to \"%s\""] =
   "Impossible de copier \"%s\" vers \"%s\"";
$_locale["Fail to delete '%s'"] =
   "Impossible d'effacer '%s'";
$_locale["Fail to rename \"%s\" !"] =
   "Impossible de renommer \"%s\" !";
$_locale["Fail to rmdir '%s'"] =
   "Impossible d'effacer le rpertoire '%s'";
$_locale["Fatal error !"] =
   "Erreur fatale !";
$_locale["File '%s' is deleted"] =
   "Le fichier '%s' est effac";
$_locale["File does not exist"] =
   "Erreur : l'archive n'existe pas";
$_locale["FindPage"] =
   "TrouvePage";
$_locale["Found %s matching %s out of %s total pages"] =
   "Trouv %s s'appariant avec %s sur un total de %s pages";
$_locale["FrontPage"] =
   "PageAccueil";
$_locale["Full text search for \"%s\""] =
   "Recherche en texte intgral pour \"%s\"";
$_locale["Go back or return to %s"] =
   "Revenir en arrire ou retourner  %s";
$_locale["Goto Editor"] =
   "Aller  l'diteur";
$_locale["Goto UserPreferences"] =
   "Aller  UserPreferences";
$_locale["HelpContents"] =
   "SommaireAide";
$_locale["ID does not exists !"] =
   "Erreur : l'archive n'existe pas";
$_locale["If you want to custumize your quicklinks, just make your ID and register your email address in the UserPreferences."] =
   "Si vous voulez particulariser les liens rapides, construire votre ID et enregistrez votre adresse email dans les UserPreferences.";
$_locale["If you want to subscribe this page please contact the WikiMaster to activate the e-mail notification"] =
   "Si vous voulez vous abonner  cette page, merci de contacter le WikiMasterpour activer la notification par email";
$_locale["If you want to subscribe this page, just make your ID and register your email address in the UserPreferences."] =
   "Si vous voulez vous abonner  cette page, construire votre ID et enregistrer votre adresse de messagerie dans UserPreferences.";
$_locale["Invalid password !"] =
   "Merci d'entrer un mot de passe valide";
$_locale["Invalid search expression \"%s\""] =
   "Expression de recherche \"%s\" invalide";
$_locale["Is it valid action ?"] =
   "Est-ce que c'est une action valide ?";
$_locale["It is a XML format !"] =
   "C'est un format XML !";
$_locale["It's today."] =
   "C'est aujourd'hui.";
$_locale["Join"] =
   "Se joindre ";
$_locale["LikePages"] =
   "PagesSimilaires";
$_locale["Login"] =
   "Se connecter";
$_locale["Login or Join"] =
   "Se connecter ou se joindre ";
$_locale["Login:"] =
   "Identifiant de connection :";
$_locale["Logout"] =
   "Se dconnecter";
$_locale["Mails are sent successfully"] =
   "Mail envoy avec succs";
$_locale["Make profile"] =
   "Faire un profil";
$_locale["New password"] =
   "Nouveau mot de passe";
$_locale["No TrackBack entry found for %s"] =
   "Aucune entre de TrackBack dtect pour %s";
$_locale["No TwinPages found."] =
   "Aucune TwinPages trouv";
$_locale["No difference found"] =
   "Aucune diffrence trouv";
$_locale["No filename given"] =
   "Aucun nom de fichier donn";
$_locale["No files are selected !"] =
   "Aucun fichier n'est slectionn !";
$_locale["No manpage found"] =
   "Aucune page de manuel trouv";
$_locale["No manpage selected"] =
   "Aucune page de manuel slectionn";
$_locale["No older revisions available"] =
   "Aucune rvision plus ancienne disponible";
$_locale["No subscribers found."] =
   "Aucun abonn trouv.";
$_locale["Nobody subscribed to this page."] =
   "Personne n'est abonn  cette page, aucun mail envoy";
$_locale["NotEditable"] =
   "Pasditable";
$_locale["Only WikiMaster can rename this page"] =
   "Seulement le WikiMaster peut renommer cette page";
$_locale["Password"] =
   "Mot de passe";
$_locale["Password:"] =
   "Mot de passe :";
$_locale["Please Login or make your ID on this Wiki ;)"] =
   "Merci de vous connecter ou de construire un ID sur ce Wiki ;)";
$_locale["Please delete this file manually."] =
   "Merci d'effacer ce fichier manuellement.";
$_locale["Please enter the valid password"] =
   "Merci d'entrer un mot de passe valide";
$_locale["Please enter your email address first."] =
   "Merci de rentrer d'abord votre adresse de messagerie";
$_locale["Please login or make your ID."] =
   "Merci de vous connectez ou de construire un ID";
$_locale["Please select a theme properly."] =
   "Merci de slectionner un thme de manire satisfaisante";
$_locale["Please try again to register your e-mail address"] =
   "Merci de rentrer d'abord votre adresse de messagerie";
$_locale["Preview"] =
   "Prvisualisation";
$_locale["Preview of %s"] =
   "Prvisualisation de %s";
$_locale["Previous"] =
   "Prcdent";
$_locale["QucikLinks are updated."] =
   "Les liens rapides ont t mis  jour.";
$_locale["RecentChanges"] =
   "ChangementsRcents";
$_locale["ReduceEditor"] =
   "Rduirediteur";
$_locale["Rename"] =
   "Renommer";
$_locale["Rename \"%s\" ?"] =
   "Renommer \"%s\" ?";
$_locale["Rename %s to %s"] =
   "Renommer %s en %s";
$_locale["Restore %s"] =
   "Restaurer %s";
$_locale["Restore %s ?"] =
   "Restaurer %s ?";
$_locale["Restore backuped data"] =
   "Restaurer des donnes sauvegardes";
$_locale["Revision History"] =
   "Historique de rvision";
$_locale["Save"] =
   "Sauvegarder";
$_locale["See %s"] =
   "Voir %s";
$_locale["See [TwinPages]:"] =
   "Voir [TwinPages]: ";
$_locale["See [TwinPages]: "] =
   "Voir [TwinPages]: ";
$_locale["Send TrackBack Ping to another Blog:"] =
   "Envoyer un ping de TrackBack  un autre blog :";
$_locale["Send TrackBack ping"] =
   "Envoy un ping de TrackBack";
$_locale["Send notification mails to all subscribers"] =
   "Envoyez un mail de notification  tous les abonns";
$_locale["Sent notification mail."] =
   "Des notifications par messagerie ont t envoyes.";
$_locale["ShowPage"] =
   "MontrePage";
$_locale["Skip to preview"] =
   "Aller  la prvisualisation";
$_locale["Someone else saved the page while you edited %s"] =
   "Quelqu'un a sauvegard la page tandis que vous ditiez %s";
$_locale["Subscribe lists updated."] =
   "Listes d'abonnement mises  jour";
$_locale["Summary of Change"] =
   "Sommaire des modifications";
$_locale["Theme cleared. Goto UserPreferences."] =
   "Thme effac. Allez  UserPreferences.";
$_locale["Title"] =
   "titre";
$_locale["Title search for \"%s\""] =
   "Recherche de titre pour \"%s\"";
$_locale["TitleIndex"] =
   "IndexTitre";
$_locale["TrackBack URL for this page:"] =
   "URL de TrackBack pour cette page :";
$_locale["TrackBack is not activated !"] =
   "Le TrackBack n'est pas activ !";
$_locale["TrackBack list of %s"] =
   "List de TrackBack de %s";
$_locale["Trackback sent"] =
   "Trackback envoy";
$_locale["Translate %s to %s"] =
   "Translate %s en %s";
$_locale["TwinPages of %s"] =
   "TwinPages de %s";
$_locale["Upload new Attachment \"%s\""] =
   "Tlcharger le nouvel attachement \"%s\"";
$_locale["Use more specific text"] =
   "Utiliser un texte plus spcifique";
$_locale["Use one of the following templates as an initial release :\n"] =
   "Utiliser un des modles de pages qui suivent pour une premirecration :\n";
$_locale["UserPreferences"] =
   "PrfrencesUtilisateur";
$_locale["Voted successfully"] =
   "Vote russi";
$_locale["Wider"] =
   "Plus large";
$_locale["You are not allowed to '%s'"] =
   "Vous n'tes pas autoris  '%s'";
$_locale["You are not allowed to '%s' on this page"] =
   "Vous n'tes pas autoris  pouvoir '%s' cette page";
$_locale["You are not allowed to '%s' on this page."] =
   "Vous n'tes pas autoris  pouvoir '%s' cette page";
$_locale["You have subscribed to this wiki page on \"%s\" for change notification.\n\n"] =
   "Vous vous tes abonn  cette page du wiki \"%s\" pour recevoir des notifications de modification.\n\n";
$_locale["Your e-mail address is confirmed successfully"] =
   "Mail envoy avec succs";
$_locale["Your email address is not valid"] =
   "Merci de rentrer d'abord votre adresse de messagerie";
$_locale["logout"] =
   "se dconnecter";
$_locale["mail does not supported by default."] =
   "La messagerie n'est pas support par dfaut.";
$_locale["mails are sent to '%s'"] =
   "un mail a t envoy  '%s'";
$_locale["or %s."] =
   "ou %s";
$_locale["or draw a new gif picture"] =
   "or Crer un nouveau dessin";
$_locale["or paste a new png picture"] =
   "or Crer un nouveau dessin";
$_locale["password again"] =
   "mot de passe de nouveau";
$_locale["send ping"] =
   "envoyer un ping";
$_locale["title"] =
   "titre";
$_locale["with revision history"] =
   "avec l'historique de rvision";

?>

==> moniwiki-1.1.4-RC9-20091012.tgz: moniwiki/locale/fr/LC_MESSAGES/moniwiki.php <==
<?php

$_locale[" or click %s to fullsearch this page.\n"] =
   " ou cliquer sur %s pour faire une recherche en texte int?gral de cette page.\n";
$_locale["\"%s\" is deleted !"] =
   "\"%s\" est effac? !";
$_locale["\"%s\" is renamed !"] =
   "\"%s\" est renomm? !";
$_locale["\"%s\" is updated"] =
   "\"%s\" est mis ? jour";
$_locale["%d comment"] =
   "%d commentaire";
$_locale["%d comments"] =
   "%d commentaires";
$_locale["%d day(s) left until %s."] =
   "%d jour(s) restent avant %s.";
$_locale["%d day(s) passed from %s."] =
   "%d jour(s) se sont pass?s depuis %s.";
$_locale["%s has saved revisions"] =
   "%s est sauvegard?";
$_locale["%s is commented successfully"] =
   "Vote r?ussi";
$_locale["%s is not allowed to upload"] =
   "%s n'est pas une action valide";
$_locale["%s is not editable"] =
   "%s n'est pas ?ditable";
$_locale["%s is not valid action"] =
   "%s n'est pas une action valide";
$_locale["%s is saved"] =
   "%s est sauvegard?";
$_locale["%s or %s"] =
   "%s ou %s";
$_locale["%s or alternativly, use one of these templates:\n"] =
   "%s ou alternativement, utiliser un de ces mod?les de page :\n";
$_locale["%s page is modified"] =
   "la page %s est modifi?";
$_locale["<b>Emphasis:</b> ''<i>italics</i>''; '''<b>bold</b>'''; '''''<b><i>bold italics</i></b>''''';\n''<i>mixed '''<b>bold</b>''' and italics</i>''; ---- horizontal rule.<br />\n<b>Headings:</b> = Title 1 =; == Title 2 ==; === Title 3 ===;\n==== Title 4 ====; ===== Title 5 =====.<br />\n<b>Lists:</b> space and one of * bullets; 1., a., A., i., I. numbered items;\n1.#n start numbering at n; space alone indents.<br />\n<b>Links:</b> JoinCapitalizedWords; [\"brackets and double quotes\"];\n[bracketed words];\nurl; [url]; [url label].<br />\n<b>Tables</b>: || cell text |||| cell text spanning two columns ||;\nno trailing white space allowed after tables or titles.<br />\n"] =
   "<b>Accentuation :</b> ''<i>italique</i>''; '''<b>gras</b>'''; '''''<b><i>italique gras</i></b>''''';\n''<i>m?lange de '''<b>gras</b>''' et italique</i>''; ---- r?gle horizontale.<br />\n<b>Ent?tes :</b> = Titre 1 =; == Titre 2 ==; === Titre 3 ===;\n==== Titre 4 ====; ===== Titre 5 =====.<br />\n<b>Listes :</b> un espace et une des * puces; 1., a., A., i., I. ?num?rations ;\n1.#n commence ? partir de n; l'espace seul provoque une indentation.<br />\n<b>Liens :</b> MotsAttach?sEnMajuscules; [\"crochets et guillemets\"];\n[mots entre crochets];\nurl; [url]; [url label].<br />\n<b>Tableaux</b> : || cellule de texte |||| cellule de texte s'?tendant sur deux colonnes ||;\nLes espaces apr?s un tableau ou un titre ne sont pas autoris?s.<br />\n";
$_locale["<b>horizontal rule</b> ---- is not applied on the blog mode."] =
   "<b>Une r?gle horizontale</b> ---- ne s'applique pas au mode blog.";
$_locale["Add Blog"] =
   "Ajouter un blog";
$_locale["Add Blog entry to \"%s\""] =
   "Ajouter une entr?e de blog ? \"%s\"";
$_locale["Add Comment to \"%s\""] =
   "Ajouter un commentaire ? \"%s\"";
$_locale["Add comment"] =
   "Ajouter un commentaire";
$_locale["Anonymous"] =
   "Anonyme";
$_locale["Back to UserPreferences"] =
   "Retour ? UserPreferences";
$_locale["Blog Changes"] =
   "ModificationsBlog";
$_locale["Blog entry \"%s\" added"] =
   "Entr?e de blog ajout? ? \"%s\"";
$_locale["Blog entry added"] =
   "Entr?e de blog ajout? ?";
$_locale["Blog entry added to \"%s\""] =
   "Entr?e de blog ajout? ? \"%s\"";
$_locale["BlogChanges"] =
   "ModificationsBlog";
$_locale["BlogChanges at %s"] =
   "ModificationsBlog at %s";
$_locale["Comment"] =
   "commentaire";
$_locale["Comment added to \"%s\""] =
   "Commentaire ajout? ? \"%s\"";
$_locale["Conflict error!"] =
   "Erreur de conflit !";
$_locale["Create new picture"] =
   "Cr?er un nouveau dessin";
$_locale["Create this page"] =
   "Cr?er cette page";
$_locale["Deeper"] =
   "Plus profond";
$_locale["Delete \"%s\" ?"] =
   "Effacer \"%s\" ?";
$_locale["Delete selected files"] =
   "Effacer les fichiers s?lectionn?s";
$_locale["DeletePage"] =
   "EffacerPage";
$_locale["Describe %s here"] =
   "D?crire %s ici";
$_locale["Did you want to Backup your wiki ?"] =
   "Voulez vous faire une sauvegarde de votre wiki ?";
$_locale["Difference between r%s and r%s"] =
   "Diff?rence entre r%s et r%s";
$_locale["Difference between r%s and the current"] =
   "Diff?rence entre r%s et la version courante";
$_locale["Difference between versions"] =
   "Diff?rence entre les versions";
$_locale["Directory '%s' is deleted"] =
   "Le r?pertoire '%s' est effac?";
$_locale["Do you want to customize your quicklinks ?"] =
   "Voulez vous mettre ? jour vos liens rapides ?";
$_locale["Do you want to subscribe \"%s\" ?"] =
   "Voulez vous abonner ? \"%s\" ?";
$_locale["Don't add a signature"] =
   "Ne pas ajouter de signature";
$_locale["Draw new picture"] =
   "Faire un nouveau dessin";
$_locale["Edit Image"] =
   "?diter l'image";
$_locale["Edit drawing"] =
   "?diter le dessin";
$_locale["Edit new drawing"] =
   "?diter un nouveau dessin";
$_locale["EditText"] =
   "?ditionTexte";
$_locale["EmailNotification is not activated"] =
   "EmailNotification n'est pas activ?";
$_locale["Error: Don't try to overwrite it"] =
   "Erreur : n'essayez pas d'?crire par dessus";
$_locale["Error: No entry found!"] =
   "Erreur : entr?e non trouv? !";
$_locale["Error: Page Not found !"] =
   "Erreur : page non trouv? !";
$_locale["Error: tarball does not exists"] =
   "Erreur : l'archive n'existe pas";
$_locale["Fail to \"%s\" !"] =
   "Impossible de pouvoir \"%s\" !";
$_locale["Fail to chmod \"%s\" !"] =
   "Impossible de pouvoir \"%s\" !";
$_locale["Fail to copy \"%s\" to \"%s\""] =
   "Impossible de copier \"%s\" vers \"%s\"";
$_locale["Fail to delete '%s'"] =
   "Impossible d'effacer '%s'";
$_locale["Fail to rename \"%s\" !"] =
   "Impossible de renommer \"%s\" !";
$_locale["Fail to rmdir '%s'"] =
   "Impossible d'effacer le r?pertoire '%s'";
$_locale["Fatal error !"] =
   "Erreur fatale !";
$_locale["File '%s' is deleted"] =
   "Le fichier '%s' est effac?";
$_locale["File does not exist"] =
   "Erreur : l'archive n'existe pas";
$_locale["FindPage"] =
   "TrouvePage";
$_locale["Found %s matching %s out of %s total pages"] =
   "Trouv? %s s'appariant avec %s sur un total de %s pages";
$_locale["FrontPage"] =
   "PageAccueil";
$_locale["Full text search for \"%s\""] =
   "Recherche en texte int?gral pour \"%s\"";
$_locale["Go back or return to %s"] =
   "Revenir en arri?re ou retourner ? %s";
$_locale["Goto Editor"] =
   "Aller ? l'?diteur";
$_locale["Goto UserPreferences"] =
   "Aller ? UserPreferences";
$_locale["HelpContents"] =
   "SommaireAide";
$_locale["ID does not exists !"] =
   "Erreur : l'archive n'existe pas";
$_locale["If you want to custumize your quicklinks, just make your ID and register your email address in the UserPreferences."] =
   "Si vous voulez particulariser les liens rapides, construire votre ID et enregistrez votre adresse email dans les UserPreferences.";
$_locale["If you want to subscribe this page please contact the WikiMaster to activate the e-mail notification"] =
   "Si vous voulez vous abonner ? cette page, merci de contacter le WikiMasterpour activer la notification par email";
$_locale["If you want to subscribe this page, just make your ID and register your email address in the UserPreferences."] =
   "Si vous voulez vous abonner ? cette page, construire votre ID et enregistrer votre adresse de messagerie dans UserPreferences.";
$_locale["Invalid password !"] =
   "Merci d'entrer un mot de passe valide";
$_locale["Invalid search expression \"%s\""] =
   "Expression de recherche \"%s\" invalide";
$_locale["Is it valid action ?"] =
   "Est-ce que c'est une action valide ?";
$_locale["It is a XML format !"] =
   "C'est un format XML !";
$_locale["It's today."] =
   "C'est aujourd'hui.";
$_locale["Join"] =
   "Se joindre ?";
$_locale["LikePages"] =
   "PagesSimilaires";
$_locale["Login"] =
   "Se connecter";
$_locale["Login or Join"] =
   "Se connecter ou se joindre ?";
$_locale["Login:"] =
   "Identifiant de connection :";
$_locale["Logout"] =
   "Se d?connecter";
$_locale["Mails are sent successfully"] =
   "Mail envoy? avec succ?s";
$_locale["Make profile"] =
   "Faire un profil";
$_locale["New password"] =
   "Nouveau mot de passe";
$_locale["No TrackBack entry found for %s"] =
   "Aucune entr?e de TrackBack d?tect? pour %s";
$_locale["No TwinPages found."] =
   "Aucune TwinPages trouv?";
$_locale["No difference found"] =
   "Aucune diff?rence trouv?";
$_locale["No filename given"] =
   "Aucun nom de fichier donn?";
$_locale["No files are selected !"] =
   "Aucun fichier n'est s?lectionn? !";
$_locale["No manpage found"] =
   "Aucune page de manuel trouv?";
$_locale["No manpage selected"] =
   "Aucune page de manuel s?lectionn?";
$_locale["No older revisions available"] =
   "Aucune r?vision plus ancienne disponible";
$_locale["No subscribers found."] =
   "Aucun abonn? trouv?.";
$_locale["Nobody subscribed to this page."] =
   "Personne n'est abonn? ? cette page, aucun mail envoy?";
$_locale["NotEditable"] =
   "Pas?ditable";
$_locale["Only WikiMaster can rename this page"] =
   "Seulement le WikiMaster peut renommer cette page";
$_locale["Password"] =
   "Mot de passe";
$_locale["Password:"] =
   "Mot de passe :";
$_locale["Please Login or make your ID on this Wiki ;)"] =
   "Merci de vous connecter ou de construire un ID sur ce Wiki ;)";
$_locale["Please delete this file manually."] =
   "Merci d'effacer ce fichier manuellement.";
$_locale["Please enter the valid password"] =
   "Merci d'entrer un mot de passe valide";
$_locale["Please enter your email address first."] =
   "Merci de rentrer d'abord votre adresse de messagerie";
$_locale["Please login or make your ID."] =
   "Merci de vous connectez ou de construire un ID";
$_locale["Please select a theme properly."] =
   "Merci de s?lectionner un th?me de mani?re satisfaisante";
$_locale["Please try again to register your e-mail address"] =
   "Merci de rentrer d'abord votre adresse de messagerie";
$_locale["Preview"] =
   "Pr?visualisation";
$_locale["Preview of %s"] =
   "Pr?visualisation de %s";
$_locale["Previous"] =
   "Pr?c?dent";
$_locale["QucikLinks are updated."] =
   "Les liens rapides ont ?t? mis ? jour.";
$_locale["Read"] =
   "Renommer";
$_locale["RecentChanges"] =
   "ChangementsR?cents";
$_locale["ReduceEditor"] =
   "R?duire?diteur";
$_locale["Rename"] =
   "Renommer";
$_locale["Rename \"%s\" ?"] =
   "Renommer \"%s\" ?";
$_locale["Rename %s to %s"] =
   "Renommer %s en %s";
$_locale["Restore %s"] =
   "Restaurer %s";
$_locale["Restore %s ?"] =
   "Restaurer %s ?";
$_locale["Restore backuped data"] =
   "Restaurer des donn?es sauvegard?es";
$_locale["Revision History"] =
   "Historique de r?vision";
$_locale["Save"] =
   "Sauvegarder";
$_locale["See %s"] =
   "Voir %s";
$_locale["See [TwinPages]:"] =
   "Voir [TwinPages]: ";
$_locale["See [TwinPages]: "] =
   "Voir [TwinPages]: ";
$_locale["Send TrackBack Ping to another Blog:"] =
   "Envoyer un ping de TrackBack ? un autre blog :";
$_locale["Send TrackBack ping"] =
   "Envoy? un ping de TrackBack";
$_locale["Send notification mails to all subscribers"] =
   "Envoyez un mail de notification ? tous les abonn?s";
$_locale["Sent notification mail."] =
   "Des notifications par messagerie ont ?t? envoy?es.";
$_locale["ShowPage"] =
   "MontrePage";
$_locale["Skip to preview"] =
   "Aller ? la pr?visualisation";
$_locale["Someone else saved the page while you edited %s"] =
   "Quelqu'un a sauvegard? la page tandis que vous ?ditiez %s";
$_locale["Subscribe lists updated."] =
   "Listes d'abonnement mises ? jour";
$_locale["Theme cleared. Goto UserPreferences."] =
   "Th?me effac?. Allez ? UserPreferences.";
$_locale["Title"] =
   "titre";
$_locale["Title search for \"%s\""] =
   "Recherche de titre pour \"%s\"";
$_locale["TitleIndex"] =
   "IndexTitre";
$_locale["TrackBack URL for this page:"] =
   "URL de TrackBack pour cette page :";
$_locale["TrackBack is not activated !"] =
   "Le TrackBack n'est pas activ? !";
$_locale["TrackBack list of %s"] =
   "List de TrackBack de %s";
$_locale["Trackback sent"] =
   "Trackback envoy?";
$_locale["Translate %s to %s"] =
   "Translate %s en %s";
$_locale["TwinPages of %s"] =
   "TwinPages de %s";
$_locale["Upload new Attachment \"%s\""] =
   "T?l?charger le nouvel attachement \"%s\"";
$_locale["Use more specific text"] =
   "Utiliser un texte plus sp?cifique";
$_locale["Use one of the following templates as an initial release :\n"] =
   "Utiliser un des mod?les de pages qui suivent pour une premi?recr?ation :\n";
$_locale["UserPreferences"] =
   "Pr?f?rencesUtilisateur";
$_locale["Voted successfully"] =
   "Vote r?ussi";
$_locale["Wider"] =
   "Plus large";
$_locale["You are not allowed to '%s'"] =
   "Vous n'?tes pas autoris? ? '%s'";
$_locale["You are not allowed to '%s' on this page"] =
   "Vous n'?tes pas autoris? ? pouvoir '%s' cette page";
$_locale["You are not allowed to '%s' on this page."] =
   "Vous n'?tes pas autoris? ? pouvoir '%s' cette page";
$_locale["You can also click %s to search title.\n"] =
   " ou cliquer sur %s pour faire une recherche en texte int?gral de cette page.\n";
$_locale["You have subscribed to this wiki page on \"%s\" for change notification.\n\n"] =
   "Vous vous ?tes abonn? ? cette page du wiki \"%s\" pour recevoir des notifications de modification.\n\n";
$_locale["Your e-mail address is confirmed successfully"] =
   "Mail envoy? avec succ?s";
$_locale["Your email address is not valid"] =
   "Merci de rentrer d'abord votre adresse de messagerie";
$_locale["logout"] =
   "se d?connecter";
$_locale["mail does not supported by default."] =
   "La messagerie n'est pas support? par d?faut.";
$_locale["mails are sent to '%s'"] =
   "un mail a ?t? envoy? ? '%s'";
$_locale["or %s."] =
   "ou %s";
$_locale["or draw a new gif picture"] =
   "or Cr?er un nouveau dessin";
$_locale["or paste a new png picture"] =
   "or Cr?er un nouveau dessin";
$_locale["password again"] =
   "mot de passe de nouveau";
$_locale["send ping"] =
   "envoyer un ping";
$_locale["title"] =
   "titre";
$_locale["with revision history"] =
   "avec l'historique de r?vision";

?>
